@@ -10,7 +10,7 @@
 
 
 test.mcnemar <- function() {
-	dataPath <- file.path(.path.package(package="clusterCrit"),"unitTests","data","testsExternal100.Rdata")
+	dataPath <- file.path(path.package(package="clusterCrit"),"unitTests","data","testsExternal100.Rdata")
 	load(file=dataPath, envir=.GlobalEnv)
 	idx <- extCriteria(clus_p2, clus_p3, c("McNemar"))
 	cat(paste("\nShould be =",17.6941604614258,"\n"))
