@@ -10,7 +10,7 @@
 
 
 test.russel_rao <- function() {
-	dataPath <- file.path(.path.package(package="clusterCrit"),"unitTests","data","testsExternal100.Rdata")
+	dataPath <- file.path(path.package(package="clusterCrit"),"unitTests","data","testsExternal100.Rdata")
 	load(file=dataPath, envir=.GlobalEnv)
 	idx <- extCriteria(clus_p2, clus_p3, c("Russel_Rao"))
 	cat(paste("\nShould be =",0.170707076787949,"\n"))
